==> axiom-1.4.0-src.zip: axiom-1.4.0/testing/axiom-testsuite/src/main/java/org/apache/axiom/ts/om/builder/TestCreateStAXOMBuilderFromXmlBeansPullParser.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.axiom.ts.om.builder;

import static com.google.common.truth.Truth.assertAbout;
import static org.apache.axiom.truth.xml.XMLTruth.xml;

import java.net.URL;

import org.apache.axiom.om.OMDocument;
import org.apache.axiom.om.OMMetaFactory;
import org.apache.axiom.om.OMXMLBuilderFactory;
import org.apache.axiom.ts.AxiomTestCase;

import za.co.eskom.nrs.xmlvend.base.x20.schema.AdviceReqDocument;

public class TestCreateStAXOMBuilderFromXmlBeansPullParser extends AxiomTestCase {
    public TestCreateStAXOMBuilderFromXmlBeansPullParser(OMMetaFactory metaFactory) {
        super(metaFactory);
    }

    @Override
    protected void runTest() throws Throwable {
        URL inputUrl = TestCreateStAXOMBuilderFromXmlBeansPullParser.class.getResource("xmlvend.xml");
        AdviceReqDocument adviceReq = AdviceReqDocument.Factory.parse(inputUrl);
        OMDocument doc = OMXMLBuilderFactory.createStAXOMBuilder(
                metaFactory.getOMFactory(), adviceReq.newXMLStreamReader()).getDocument();
        assertAbout(xml())
                .that(xml(OMDocument.class, doc))
                .ignoringElementContentWhitespace()
                .hasSameContentAs(inputUrl);
    }
}

==> axiom-2.0.0-src.zip: axiom-2.0.0/testing/axiom-testsuite/src/main/java/org/apache/axiom/ts/om/builder/TestCreateStAXOMBuilderFromXmlBeansPullParser.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.axiom.ts.om.builder;

import static com.google.common.truth.Truth.assertAbout;
import static org.apache.axiom.truth.xml.XMLTruth.xml;

import java.net.URL;

import org.apache.axiom.om.OMDocument;
import org.apache.axiom.om.OMMetaFactory;
import org.apache.axiom.om.OMXMLBuilderFactory;
import org.apache.axiom.ts.AxiomTestCase;

import za.co.eskom.nrs.xmlvend.base.x20.schema.AdviceReqDocument;

public class TestCreateStAXOMBuilderFromXmlBeansPullParser extends AxiomTestCase {
    public TestCreateStAXOMBuilderFromXmlBeansPullParser(OMMetaFactory metaFactory) {
        super(metaFactory);
    }

    @Override
    protected void runTest() throws Throwable {
        URL inputUrl =
                TestCreateStAXOMBuilderFromXmlBeansPullParser.class.getResource("xmlvend.xml");
        AdviceReqDocument adviceReq = AdviceReqDocument.Factory.parse(inputUrl);
        OMDocument doc =
                OMXMLBuilderFactory.createStAXOMBuilder(
                                metaFactory.getOMFactory(), adviceReq.newXMLStreamReader())
                        .getDocument();
        assertAbout(xml())
                .that(xml(OMDocument.class, doc))
                .ignoringElementContentWhitespace()
                .hasSameContentAs(inputUrl);
    }
}
